@@ -7,12 +7,11 @@ use strict;
 use Carp;
 use Storable qw/retrieve/;
 use List::MoreUtils qw/uniq/;
-use File::Slurp;
-use Bio::Gonzales::Util::File qw/openod/;
+use Bio::Gonzales::Util::File qw/gonzopen/;
 
 extends 'Bio::Grid::Run::SGE::Index::List';
 
-our $VERSION = '0.0386'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 around 'create' => sub {
   my $orig = shift;
@@ -26,7 +25,7 @@ around 'create' => sub {
 
   my @elements;
   for my $f (@$files) {
-    my $fh = openod( $f, '<' );
+    my $fh = gonzopen( $f, '<' );
     while (<$fh>) {
       chomp;
       push @elements, $_;
