@@ -32,5 +32,5 @@ run_job(
     }
 );
 
-exit;
+1;
 
